Index: trunk/pstamp/scripts/pstamp_queue_requests.pl
===================================================================
--- trunk/pstamp/scripts/pstamp_queue_requests.pl	(revision 27260)
+++ trunk/pstamp/scripts/pstamp_queue_requests.pl	(revision 27283)
@@ -71,7 +71,7 @@
 
 my @dataStores;
 #Look up the list of data stores to monitor
 {
-    my $command = "$pstamptool -datastore";
+    my $command = "$pstamptool -datastore -ready";
     $command .= " -dbname $dbname" if $dbname;
     $command .= " -dbserver $dbserver" if $dbserver;
@@ -71,7 +71,7 @@
 
 my @dataStores;
-#Look up the list of data stores to monitor
+#Look up the list of data stores that are ready to be queried
 {
